@@ -1,4 +1,4 @@
 from .hisat3n_general import separate_unique_and_multi_align_reads
 from .utilities import validate_cwd_fastq_paths, read_mapping_config
 from .hisat3n_mct import select_mct_reads_normal
-from .summary import snmc_summary
+from .summary import snmc_summary, snmct_summary
