@@ -1,4 +1,4 @@
-from .pipelines import prepare_run
+from .pipelines import prepare_run, start_from_cell_fastq
 from .stats import final_summary
 from .config import print_default_mapping_config
 from .stats.plot import *
